@@ -1,25 +1,9 @@
 /*
   This file is part of the KDE reminder agent.
 
-  Copyright (c) 2002,2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2002, 2003 Cornelius Schumacher <schumacher@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "koalarmclient.h"
@@ -187,7 +171,7 @@ bool KOAlarmClient::collectionsAvailable() const
     for (int row = 0; row < rowCount; ++row) {
         static const int column = 0;
         const QModelIndex index = mETM->index(row, column);
-        bool haveData
+        const bool haveData
             = mETM->data(index, Akonadi::EntityTreeModel::IsPopulatedRole).toBool();
         if (!haveData) {
             return false;
@@ -212,7 +196,7 @@ void KOAlarmClient::checkAlarms()
         return;
     }
 
-    QDateTime from = mLastChecked.addSecs(1);
+    const QDateTime from = mLastChecked.addSecs(1);
     mLastChecked = QDateTime::currentDateTime();
 
     qCDebug(KOALARMCLIENT_LOG) << "Check:" << from.toString() << " -" << mLastChecked.toString();
