@@ -1,31 +1,15 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2002 Mike Pilone <mpilone@slac.com>
-  Copyright (c) 2002 Don Sanders <sanders@kde.org>
-  Copyright (c) 2004 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-  Copyright (c) 2010-2020 Laurent Montel <montel@kde.org>
-  Copyright (c) 2012-2019 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 2002 Mike Pilone <mpilone@slac.com>
+  SPDX-FileCopyrightText: 2002 Don Sanders <sanders@kde.org>
+  SPDX-FileCopyrightText: 2004 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2010-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2019 Allen Winter <winter@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #include <config-korganizer.h>
 #include "actionmanager.h"
@@ -94,10 +78,6 @@ KOWindowList *ActionManager::mWindowList = nullptr;
 
 ActionManager::ActionManager(KXMLGUIClient *client, CalendarView *widget, QObject *parent, KOrg::MainWindow *mainWindow, bool isPart, QMenuBar *menuBar)
     : QObject(parent)
-    , mCollectionViewShowAction(nullptr)
-    , mCollectionView(nullptr)
-    , mCollectionViewStateSaver(nullptr)
-    , mCollectionSelectionModelStateSaver(nullptr)
 {
     new KOrgCalendarAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/Calendar"), this);
@@ -106,7 +86,6 @@ ActionManager::ActionManager(KXMLGUIClient *client, CalendarView *widget, QObjec
     mACollection = mGUIClient->actionCollection();
     mCalendarView = widget;
     mIsPart = isPart;
-    mTempFile = nullptr;
     mMainWindow = mainWindow;
     mMenuBar = menuBar;
 }
@@ -225,7 +204,7 @@ void ActionManager::createCalendarAkonadi()
 
     mCollectionView->setCollectionSelectionProxyModel(checkableProxy);
 
-    CalendarSupport::CollectionSelection *collectionSelection
+    auto *collectionSelection
         = new CalendarSupport::CollectionSelection(selectionModel);
     EventViews::EventView::setGlobalCollectionSelection(collectionSelection);
 
@@ -242,7 +221,6 @@ void ActionManager::createCalendarAkonadi()
 
 void ActionManager::initActions()
 {
-    QAction *action = nullptr;
 
     /*************************** FILE MENU **********************************/
 
@@ -278,6 +256,7 @@ void ActionManager::initActions()
     mACollection->addAction(QStringLiteral("import_icalendar"), mImportAction);
     connect(mImportAction, &QAction::triggered, this, &ActionManager::file_import);
 
+    QAction *action = nullptr;
     /** Get Hot New Stuff Action **/
     //TODO: Icon
     if (KAuthorized::authorize(QStringLiteral("ghns"))) {
@@ -885,7 +864,7 @@ void ActionManager::slotMergeFinished(bool success, int total)
 {
     Q_ASSERT(sender());
     mImportAction->setEnabled(true);
-    Akonadi::ICalImporter *importer = qobject_cast<Akonadi::ICalImporter *>(sender());
+    auto *importer = qobject_cast<Akonadi::ICalImporter *>(sender());
 
     if (success) {
         mCalendarView->showMessage(i18np("1 incidence was imported successfully.",
@@ -902,7 +881,7 @@ void ActionManager::slotMergeFinished(bool success, int total)
 void ActionManager::slotNewResourceFinished(bool success)
 {
     Q_ASSERT(sender());
-    Akonadi::ICalImporter *importer = qobject_cast<Akonadi::ICalImporter *>(sender());
+    auto *importer = qobject_cast<Akonadi::ICalImporter *>(sender());
     mImportAction->setEnabled(true);
     if (success) {
         mCalendarView->showMessage(i18n("New calendar added successfully"),
@@ -1017,7 +996,7 @@ void ActionManager::file_archive()
 
 bool ActionManager::importURL(const QUrl &url, bool merge)
 {
-    Akonadi::ICalImporter *importer = new Akonadi::ICalImporter();
+    auto *importer = new Akonadi::ICalImporter();
     bool jobStarted;
     if (merge) {
         connect(importer, &Akonadi::ICalImporter::importIntoExistingFinished, this,
@@ -1435,7 +1414,7 @@ protected:
     QAction *mDelete = nullptr;
 };
 
-void ActionManager::processIncidenceSelection(const Akonadi::Item &item, const QDate &date)
+void ActionManager::processIncidenceSelection(const Akonadi::Item &item, QDate date)
 {
     //qCDebug(KORGANIZER_LOG) << "ActionManager::processIncidenceSelection()";
     Q_UNUSED(date);
@@ -1537,7 +1516,7 @@ void ActionManager::openEventEditor(const QString &summary, const QString &descr
         action = IncidenceEditorNG::IncidenceEditorSettings::Link;
     } else if (IncidenceEditorNG::IncidenceEditorSettings::self()->defaultEmailAttachMethod()
                == IncidenceEditorNG::IncidenceEditorSettings::Ask) {
-        QMenu *menu = new QMenu(nullptr);
+        auto *menu = new QMenu(nullptr);
         QAction *attachLink = menu->addAction(i18n("Attach as &link"));
         QAction *attachInline = menu->addAction(i18n("Attach &inline"));
         QAction *attachBody = menu->addAction(i18n("Attach inline &without attachments"));
@@ -1574,7 +1553,7 @@ void ActionManager::openEventEditor(const QString &summary, const QString &descr
         if (!f.open(QFile::ReadOnly)) {
             return;
         }
-        KMime::Message *msg = new KMime::Message();
+        auto *msg = new KMime::Message();
         msg->setContent(f.readAll());
         msg->parse();
         if (msg == msg->textContent() || msg->textContent() == nullptr) {   // no attachments
@@ -1589,7 +1568,7 @@ void ActionManager::openEventEditor(const QString &summary, const QString &descr
                 delete msg;
                 return;
             }
-            KMime::Message *newMsg = new KMime::Message();
+            auto *newMsg = new KMime::Message();
             newMsg->setHead(msg->head());
             newMsg->setBody(msg->textContent()->body());
             newMsg->parse();
@@ -1634,7 +1613,7 @@ void ActionManager::openTodoEditor(const QString &summary, const QString &descri
     if (attachmentMimetype != QLatin1String("message/rfc822")) {
         action = KOPrefs::TodoAttachLink;
     } else if (KOPrefs::instance()->defaultTodoAttachMethod() == KOPrefs::TodoAttachAsk) {
-        QMenu *menu = new QMenu(nullptr);
+        auto *menu = new QMenu(nullptr);
         QAction *attachLink = menu->addAction(i18n("Attach as &link"));
         QAction *attachInline = menu->addAction(i18n("Attach &inline"));
         menu->addSeparator();
@@ -1669,12 +1648,12 @@ void ActionManager::openTodoEditor(const QString &summary, const QString &descri
                            action != KOPrefs::TodoAttachLink);
 }
 
-void ActionManager::openJournalEditor(const QDate &date)
+void ActionManager::openJournalEditor(QDate date)
 {
     mCalendarView->newJournal(date);
 }
 
-void ActionManager::openJournalEditor(const QString &text, const QDate &date)
+void ActionManager::openJournalEditor(const QString &text, QDate date)
 {
     mCalendarView->newJournal(text, date);
 }
@@ -1699,17 +1678,17 @@ void ActionManager::showEventView()
     mCalendarView->viewManager()->showEventView();
 }
 
-void ActionManager::goDate(const QDate &date)
+void ActionManager::goDate(QDate date)
 {
     mCalendarView->goDate(date);
 }
 
-void ActionManager::goDate(const QString &date)
+void ActionManager::goDate(QString date)
 {
     goDate(QLocale().toDate(date));
 }
 
-void ActionManager::showDate(const QDate &date)
+void ActionManager::showDate(QDate date)
 {
     mCalendarView->showDate(date);
 }
