@@ -1,29 +1,13 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2002 Mike Pilone <mpilone@slac.com>
-  Copyright (c) 2002 Don Sanders <sanders@kde.org>
-  Copyright (c) 2003,2004 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2002 Mike Pilone <mpilone@slac.com>
+  SPDX-FileCopyrightText: 2002 Don Sanders <sanders@kde.org>
+  SPDX-FileCopyrightText: 2003, 2004 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef KORG_ACTIONMANAGER_H
@@ -158,17 +142,17 @@ public Q_SLOTS:
     void openTodoEditor(const QString &summary, const QString &description, const QString &uri, const QString &file, const QStringList &attendees, const QString &attachmentMimetype);
     void openTodoEditor(const QString &summary, const QString &description, const QStringList &attachmentUris, const QStringList &attendees, const QStringList &attachmentMimetypes, bool attachmentIsInline);
 
-    void openJournalEditor(const QDate &date);
-    void openJournalEditor(const QString &text, const QDate &date);
+    void openJournalEditor(QDate date);
+    void openJournalEditor(const QString &text, QDate date);
     void openJournalEditor(const QString &text);
 
     void showJournalView();
     void showTodoView();
     void showEventView();
 
-    void goDate(const QDate &);
-    void goDate(const QString &);
-    void showDate(const QDate &date);
+    void goDate(QDate);
+    void goDate(QString);
+    void showDate(QDate date);
 
 public:
     QString localFileName();
@@ -195,7 +179,7 @@ public Q_SLOTS:
     */
     void updateConfig();
 
-    void processIncidenceSelection(const Akonadi::Item &item, const QDate &date);
+    void processIncidenceSelection(const Akonadi::Item &item, QDate date);
     void keyBindings();
 
     /**
