@@ -1,29 +1,13 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2001,2002,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2001, 2002, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
-  Author: Sergio Martins <sergio@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Sergio Martins <sergio@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "datenavigatorcontainer.h"
@@ -242,7 +226,7 @@ void DateNavigatorContainer::resizeAllContents()
         }
 
         while (count > (mExtraViews.count() + 1)) {
-            KDateNavigator *n = new KDateNavigator(this);
+            auto *n = new KDateNavigator(this);
             mExtraViews.append(n);
             n->setCalendar(mCalendar);
             connectNavigatorView(n);
@@ -367,7 +351,7 @@ QDate DateNavigatorContainer::monthOfNavigator(int navigatorIndex) const
     if (navigatorIndex <= mExtraViews.count() && navigatorIndex >= 0) {
         return mExtraViews[navigatorIndex - 1]->month();
     } else {
-        return QDate();
+        return {};
     }
 }
 
