@@ -1,23 +1,10 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2004 Tobias Koenig <tokoe@kde.org>
-  Copyright (c) 2004 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2004 Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2004 Cornelius Schumacher <schumacher@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kcmdesignerfields.h"
@@ -53,7 +40,6 @@ public:
     PageItem(QTreeWidget *parent, const QString &path)
         : QTreeWidgetItem(parent)
         , mPath(path)
-        , mIsActive(false)
     {
         setFlags(flags() | Qt::ItemIsUserCheckable);
         setCheckState(0, Qt::Unchecked);
@@ -135,9 +121,9 @@ public:
 
 private:
     QString mName;
-    QString mPath;
+    const QString mPath;
     QPixmap mPreview;
-    bool mIsActive;
+    bool mIsActive = false;
 };
 
 KCMDesignerFields::KCMDesignerFields(QWidget *parent, const QVariantList &args)
@@ -171,7 +157,7 @@ void KCMDesignerFields::delayedInit()
     load();
 
     // Install a dirwatcher that will detect newly created or removed designer files
-    KDirWatch *dw = new KDirWatch(this);
+    auto *dw = new KDirWatch(this);
     QDir().mkpath(localUiDir());
     dw->addDir(localUiDir(), KDirWatch::WatchFiles);
     connect(dw, &KDirWatch::created, this, &KCMDesignerFields::rebuildList);
@@ -183,7 +169,7 @@ void KCMDesignerFields::deleteFile()
 {
     const auto selectedItems = mPageView->selectedItems();
     for (QTreeWidgetItem *item : selectedItems) {
-        PageItem *pageItem = static_cast<PageItem *>(item->parent() ? item->parent() : item);
+        auto *pageItem = static_cast<PageItem *>(item->parent() ? item->parent() : item);
         if (KMessageBox::warningContinueCancel(
                 this,
                 i18n("<qt>Do you really want to delete '<b>%1</b>'?</qt>",
@@ -241,7 +227,7 @@ void KCMDesignerFields::loadActivePages(const QStringList &ai)
     QTreeWidgetItemIterator it(mPageView);
     while (*it) {
         if ((*it)->parent() == nullptr) {
-            PageItem *item = static_cast<PageItem *>(*it);
+            auto *item = static_cast<PageItem *>(*it);
             if (ai.contains(item->name())) {
                 item->setCheckState(0, Qt::Checked);
                 item->setIsActive(true);
@@ -269,7 +255,7 @@ QStringList KCMDesignerFields::saveActivePages()
     QStringList activePages;
     while (*it) {
         if ((*it)->parent() == nullptr) {
-            PageItem *item = static_cast<PageItem *>(*it);
+            auto *item = static_cast<PageItem *>(*it);
             activePages.append(item->name());
         }
 
@@ -290,8 +276,8 @@ void KCMDesignerFields::defaults()
 
 void KCMDesignerFields::initGUI()
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    auto *layout = new QVBoxLayout(this);
+    layout->setContentsMargins({});
 
     bool noDesigner = QStandardPaths::findExecutable(QStringLiteral("designer")).isEmpty();
 
@@ -303,7 +289,7 @@ void KCMDesignerFields::initGUI()
         layout->addWidget(lbl);
     }
 
-    QHBoxLayout *hbox = new QHBoxLayout();
+    auto *hbox = new QHBoxLayout();
     layout->addLayout(hbox);
 
     mPageView = new QTreeWidget(this);
@@ -314,7 +300,7 @@ void KCMDesignerFields::initGUI()
     hbox->addWidget(mPageView);
 
     QGroupBox *box = new QGroupBox(i18n("Preview of Selected Page"), this);
-    QVBoxLayout *boxLayout = new QVBoxLayout(box);
+    auto *boxLayout = new QVBoxLayout(box);
 
     mPagePreview = new QLabel(box);
     mPagePreview->setMinimumWidth(300);
@@ -404,12 +390,12 @@ void KCMDesignerFields::updatePreview()
 
             mPageDetails->setText(details);
 
-            PageItem *pageItem = static_cast<PageItem *>(item->parent());
+            auto *pageItem = static_cast<PageItem *>(item->parent());
             mPagePreview->setWindowIcon(pageItem->preview());
         } else {
             mPageDetails->setText(QString());
 
-            PageItem *pageItem = static_cast<PageItem *>(item);
+            auto *pageItem = static_cast<PageItem *>(item);
             mPagePreview->setWindowIcon(pageItem->preview());
 
             widgetItemSelected = true;
@@ -431,7 +417,7 @@ void KCMDesignerFields::itemClicked(QTreeWidgetItem *item)
         return;
     }
 
-    PageItem *pageItem = static_cast<PageItem *>(item);
+    auto *pageItem = static_cast<PageItem *>(item);
 
     if (pageItem->isOn() != pageItem->isActive()) {
         Q_EMIT changed(true);
@@ -456,7 +442,7 @@ void KCMDesignerFields::startDesigner()
         item = mPageView->selectedItems().first();
     }
     if (item) {
-        PageItem *pageItem = static_cast<PageItem *>(item->parent() ? item->parent() : item);
+        auto *pageItem = static_cast<PageItem *>(item->parent() ? item->parent() : item);
         args.append(pageItem->path());
     }
 
