@@ -1,27 +1,11 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 1999 Preston Brown <pbrown@kde.org>
-  Copyright (c) 2000,2001,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 1999 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2000, 2001, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "koapp.h"
@@ -75,7 +59,6 @@ int KOrganizerApp::activate(const QStringList &args, const QString &workingDir)
     korganizer_options(&parser);
     parser.process(args);
 
-
     if (parser.isSet(QStringLiteral("view"))) {
         processCalendar(QUrl(), false);
         const auto url = QUrl{parser.value(QStringLiteral("view"))};
@@ -83,18 +66,18 @@ int KOrganizerApp::activate(const QStringList &args, const QString &workingDir)
         fetchJob->fetchScope().fetchFullPayload();
         connect(fetchJob, &Akonadi::ItemFetchJob::result,
                 this, [](KJob *job) {
-                    if (job->error()) {
-                        KMessageBox::detailedSorry(nullptr, i18n("Failed to retrieve incidence from Akonadi"), job->errorText());
-                        return;
-                    }
-                    auto fetchJob = static_cast<Akonadi::ItemFetchJob*>(job);
-                    if (fetchJob->count() != 1) {
-                        KMessageBox::sorry(nullptr, i18n("Failed to retrieve incidence from Akonadi: requested incidence doesn't exist."));
-                        return;
-                    }
-                    KOrg::MainWindow *korg = ActionManager::findInstance(QUrl());
-                    korg->actionManager()->view()->showIncidence(fetchJob->items().first());
-               });
+            if (job->error()) {
+                KMessageBox::detailedSorry(nullptr, i18n("Failed to retrieve incidence from Akonadi"), job->errorText());
+                return;
+            }
+            auto fetchJob = static_cast<Akonadi::ItemFetchJob *>(job);
+            if (fetchJob->count() != 1) {
+                KMessageBox::sorry(nullptr, i18n("Failed to retrieve incidence from Akonadi: requested incidence doesn't exist."));
+                return;
+            }
+            KOrg::MainWindow *korg = ActionManager::findInstance(QUrl());
+            korg->actionManager()->view()->showIncidence(fetchJob->items().first());
+        });
         return 0;
     }
 
