@@ -1,25 +1,9 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2002,2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2002, 2003 Cornelius Schumacher <schumacher@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "koglobals.h"
@@ -86,7 +70,7 @@ int KOGlobals::firstDayOfWeek() const
     return KOPrefs::instance()->mWeekStartDay + 1;
 }
 
-QList<QDate> KOGlobals::workDays(const QDate &startDate, const QDate &endDate) const
+QList<QDate> KOGlobals::workDays(QDate startDate, QDate endDate) const
 {
     QList<QDate> result;
 
@@ -125,7 +109,7 @@ void KOGlobals::setHolidays(const QStringList &regions)
     qDeleteAll(mHolidayRegions);
     mHolidayRegions.clear();
     for (const QString &regionStr : regions) {
-        KHolidays::HolidayRegion *region = new KHolidays::HolidayRegion(regionStr);
+        auto *region = new KHolidays::HolidayRegion(regionStr);
         if (region->isValid()) {
             mHolidayRegions.append(region);
         } else {
