@@ -1,31 +1,15 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 1997, 1998, 1999  Preston Brown <preston.brown@yale.edu>
-  Fester Zigterman <F.J.F.ZigtermanRustenburg@student.utwente.nl>
-  Ian Dawes <iadawes@globalserve.net>
-  Laszlo Boloni <boloni@cs.purdue.edu>
+  SPDX-FileCopyrightText: 1997, 1998, 1999 Preston Brown <preston.brown@yale.edu>
+  SPDX-FileCopyrightText: Fester Zigterman <F.J.F.ZigtermanRustenburg@student.utwente.nl>
+  SPDX-FileCopyrightText: Ian Dawes <iadawes@globalserve.net>
+  SPDX-FileCopyrightText: Laszlo Boloni <boloni@cs.purdue.edu>
 
-  Copyright (c) 2000-2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2000-2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "korganizer.h"
@@ -70,7 +54,7 @@ KOrganizer::KOrganizer() : KParts::MainWindow()
     (void)new KOrganizerIfaceImpl(mActionManager, this, QStringLiteral("IfaceImpl"));
 
 #ifdef WITH_KUSERFEEDBACK
-    KUserFeedback::NotificationPopup *userFeedBackNotificationPopup = new KUserFeedback::NotificationPopup(this);
+    auto *userFeedBackNotificationPopup = new KUserFeedback::NotificationPopup(this);
     userFeedBackNotificationPopup->setFeedbackProvider(UserFeedBackManager::self()->userFeedbackProvider());
 #endif
 }
@@ -102,7 +86,7 @@ void KOrganizer::init(bool document)
 
     bar->addWidget(new QLabel(this));
 
-    KPIM::ProgressStatusBarWidget *progressBar
+    auto *progressBar
         = new KPIM::ProgressStatusBarWidget(statusBar(), this);
 
     bar->addPermanentWidget(progressBar->littleProgress());
@@ -142,7 +126,7 @@ void KOrganizer::initializePluginActions()
 
 void KOrganizer::newMainWindow(const QUrl &url)
 {
-    KOrganizer *korg = new KOrganizer();
+    auto *korg = new KOrganizer();
     if (url.isValid() || url.isEmpty()) {
         korg->init(true);
         if (mActionManager->importURL(url, false) || url.isEmpty()) {
