@@ -1,26 +1,10 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef KORG_KOVIEWMANAGER_H
@@ -80,17 +64,12 @@ public:
     void readSettings(KConfig *config);
     void writeSettings(KConfig *config);
 
-    /** Read which view was shown last from config file */
-    void readCurrentView(KConfig *config);
-    /** Write which view is currently shown to config file */
-    void writeCurrentView(KConfig *config);
-
     KOrg::BaseView *currentView();
 
     void setDocumentId(const QString &);
 
     void updateView();
-    void updateView(const QDate &start, const QDate &end, const QDate &preferredMonth);
+    void updateView(QDate start, QDate end, QDate preferredMonth);
 
     void goMenu(bool enable);
     void raiseCurrentView();
@@ -185,7 +164,7 @@ private Q_SLOTS:
 private:
     QWidget *widgetForView(KOrg::BaseView *) const;
     QList<KOrg::BaseView *> mViews;
-    CalendarView *mMainView = nullptr;
+    CalendarView *const mMainView;
 
     KOAgendaView *mAgendaView = nullptr;
     KOrg::MultiAgendaView *mAgendaSideBySideView = nullptr;
@@ -199,9 +178,9 @@ private:
 
     KOrg::BaseView *mLastEventView = nullptr;
     QTabWidget *mAgendaViewTabs = nullptr;
-    int mAgendaViewTabIndex;
+    int mAgendaViewTabIndex = 0;
 
-    RangeMode mRangeMode;
+    RangeMode mRangeMode = NO_RANGE;
 };
 
 #endif
