@@ -1,23 +1,7 @@
 /*
- * Copyright (C) 2014 Christian Mollekopf <mollekopf@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Christian Mollekopf <mollekopf@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #include <QObject>
@@ -45,7 +29,7 @@ public:
 
     bool operator==(const Node &node) const override
     {
-        const DummyNode *dummyNode = dynamic_cast<const DummyNode *>(&node);
+        const auto *dummyNode = dynamic_cast<const DummyNode *>(&node);
         if (dummyNode) {
             return dummyNode->mUid == mUid;
         }
@@ -168,7 +152,7 @@ QModelIndex getIndex(const char *string, const QAbstractItemModel &model)
         = model.match(model.index(0, 0), Qt::DisplayRole, QString::fromLatin1(
                           string), 1, Qt::MatchRecursive);
     if (list.isEmpty()) {
-        return QModelIndex();
+        return {};
     }
     return list.first();
 }
