@@ -1,23 +1,7 @@
 /*
- * Copyright (c) 2014 Christian Mollekopf <mollekopf@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Christian Mollekopf <mollekopf@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #include "calendardelegate.h"
@@ -49,7 +33,7 @@ StyledCalendarDelegate::~StyledCalendarDelegate()
 {
 }
 
-static QRect enableButtonRect(const QRect &rect, int pos = 1)
+static QRect enableButtonRect(QRect rect, int pos = 1)
 {
     //2px border on each side of the icon
     static int border = 2;
@@ -61,7 +45,7 @@ static QRect enableButtonRect(const QRect &rect, int pos = 1)
 static QStyle *style(const QStyleOptionViewItem &option)
 {
     QWidget const *widget = nullptr;
-    if (const QStyleOptionViewItem *v3 = qstyleoption_cast<const QStyleOptionViewItem *>(&option)) {
+    if (const auto *v3 = qstyleoption_cast<const QStyleOptionViewItem *>(&option)) {
         widget = v3->widget;
     }
     QStyle *style = widget ? widget->style() : QApplication::style();
@@ -77,7 +61,7 @@ static QStyleOptionButton buttonOpt(const QStyleOptionViewItem &opt, const QPixm
     option.rect = enableButtonRect(r, pos);
     option.state = QStyle::State_Active | QStyle::State_Enabled;
     option.iconSize = QSize(h, h);
-    QWidget *w = const_cast<QWidget *>(opt.widget);
+    auto *w = const_cast<QWidget *>(opt.widget);
     if (w) {
         const Akonadi::Collection col = CalendarSupport::collectionFromIndex(index);
         w->setToolTip(CalendarSupport::toolTipString(col));
@@ -180,7 +164,7 @@ bool StyledCalendarDelegate::editorEvent(QEvent *event, QAbstractItemModel *mode
     // make sure that we have the right event type
     if ((event->type() == QEvent::MouseButtonRelease)
         || (event->type() == QEvent::MouseButtonPress)) {
-        QMouseEvent *me = static_cast<QMouseEvent *>(event);
+        auto *me = static_cast<QMouseEvent *>(event);
 
         for (int i = 1; i < 4; i++) {
             if (enableButtonRect(option.rect, i).contains(me->pos())) {
