@@ -1,23 +1,7 @@
 /*
- * Copyright 2014  Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #include "quickview.h"
@@ -32,7 +16,6 @@
 #include <KCalendarCore/MemoryCalendar>
 
 #include <EventViews/AgendaView>
-#include <EventViews/ViewCalendar>
 #include <CalendarSupport/Utils>
 
 #include <KCheckableProxyModel>
@@ -48,11 +31,10 @@ Quickview::Quickview(const Akonadi::Collection &col)
     : QDialog()
     , mUi(new Ui_quickview)
     , mCollection(col)
-    , mDayRange(7)
 {
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mainWidget);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &Quickview::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &Quickview::reject);
@@ -68,7 +50,7 @@ Quickview::Quickview(const Akonadi::Collection &col)
     mUi->mDayBtn->hide();
 
     //create etm for mCollection
-    Akonadi::ChangeRecorder *monitor = new Akonadi::ChangeRecorder(this);
+    auto *monitor = new Akonadi::ChangeRecorder(this);
     Akonadi::ItemFetchScope scope;
     const QStringList allMimeTypes
         = { KCalendarCore::Event::eventMimeType(), KCalendarCore::Todo::todoMimeType(),
