@@ -1,23 +1,7 @@
 /*
- * Copyright (C) 2014 Christian Mollekopf <mollekopf@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Christian Mollekopf <mollekopf@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #include "reparentingmodel.h"
@@ -32,14 +16,12 @@
  */
 
 ReparentingModel::Node::Node(ReparentingModel &model)
-    :   parent(nullptr)
-    , personModel(model)
-    , mIsSourceNode(false)
+    : personModel(model)
 {
 }
 
 ReparentingModel::Node::Node(ReparentingModel &model, ReparentingModel::Node *p, const QModelIndex &srcIndex)
-    :   sourceIndex(srcIndex)
+    : sourceIndex(srcIndex)
     , parent(p)
     , personModel(model)
     , mIsSourceNode(true)
@@ -626,7 +608,7 @@ ReparentingModel::Node *ReparentingModel::extractNode(const QModelIndex &index)
 QModelIndex ReparentingModel::index(int row, int column, const QModelIndex &parent) const
 {
     if (row < 0 || column != 0) {
-        return QModelIndex();
+        return {};
     }
     // qCDebug(KORGANIZER_LOG) << parent << row;
     const Node *parentNode;
@@ -648,7 +630,7 @@ QModelIndex ReparentingModel::index(int row, int column, const QModelIndex &pare
 QModelIndex ReparentingModel::mapToSource(const QModelIndex &idx) const
 {
     if (!idx.isValid() || !sourceModel()) {
-        return QModelIndex();
+        return {};
     }
     Node *node = extractNode(idx);
     if (!node->isSourceNode()) {
@@ -673,7 +655,7 @@ QModelIndex ReparentingModel::mapFromSource(const QModelIndex &sourceIndex) cons
 {
     // qCDebug(KORGANIZER_LOG) << sourceIndex << sourceIndex.data().toString();
     if (!sourceIndex.isValid()) {
-        return QModelIndex();
+        return {};
     }
     Node *node = getSourceNode(sourceIndex);
     if (!node) {
@@ -825,7 +807,7 @@ QModelIndex ReparentingModel::index(Node *node) const
 {
     const int r = row(node);
     if (r < 0) {
-        return QModelIndex();
+        return {};
     }
     return createIndex(r, 0, node);
 }
@@ -834,7 +816,7 @@ QModelIndex ReparentingModel::parent(const QModelIndex &child) const
 {
     // qCDebug(KORGANIZER_LOG) << child << child.data().toString();
     if (!child.isValid()) {
-        return QModelIndex();
+        return {};
     }
     const Node *node = extractNode(child);
     return index(node->parent);
@@ -843,7 +825,7 @@ QModelIndex ReparentingModel::parent(const QModelIndex &child) const
 QModelIndex ReparentingModel::buddy(const QModelIndex &index) const
 {
     if (!index.isValid() || !sourceModel()) {
-        return QModelIndex();
+        return {};
     }
     Node *node = extractNode(index);
     if (node->isSourceNode()) {
