@@ -1,21 +1,9 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2007 Volker Krause <vkrause@kde.org>
+  SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "multiagendaview.h"
@@ -53,7 +41,7 @@ class MultiAgendaView::Private
 public:
     Private(MultiAgendaView *qq) : q(qq)
     {
-        QHBoxLayout *layout = new QHBoxLayout(q);
+        auto *layout = new QHBoxLayout(q);
         mMultiAgendaView = new EventViews::MultiAgendaView(q);
         mMultiAgendaView->setPreferences(KOPrefs::instance()->eventViewsPreferences());
         layout->addWidget(mMultiAgendaView);
@@ -323,7 +311,7 @@ MultiAgendaViewConfigDialog::MultiAgendaViewConfigDialog(QAbstractItemModel *bas
     , d(new Private(baseModel, this))
 {
     setWindowTitle(i18nc("@title:window", "Configure Side-By-Side View"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     QWidget *widget = new QWidget;
     d->ui.setupUi(widget);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(
@@ -382,7 +370,7 @@ void MultiAgendaViewConfigDialog::useCustomToggled(bool on)
 AkonadiCollectionView *MultiAgendaViewConfigDialog::Private::createView(
     KCheckableProxyModel *model)
 {
-    AkonadiCollectionView *cview = new AkonadiCollectionView(nullptr, false, q);
+    auto *cview = new AkonadiCollectionView(nullptr, false, q);
     cview->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     cview->setCollectionSelectionProxyModel(model);
     return cview;
@@ -413,7 +401,7 @@ void MultiAgendaViewConfigDialog::Private::setUpColumns(int n)
     } else {
         selections.resize(n);
         for (int i = oldN; i < n; ++i) {
-            QStandardItem *item = new QStandardItem;
+            auto *item = new QStandardItem;
             item->setEditable(false);
             if (titles.count() <= i) {
                 titles.resize(i + 1);
@@ -423,20 +411,20 @@ void MultiAgendaViewConfigDialog::Private::setUpColumns(int n)
             item->setData(i, Qt::UserRole);
             listModel.appendRow(item);
 
-            QSortFilterProxyModel *sortProxy = new QSortFilterProxyModel;
+            auto *sortProxy = new QSortFilterProxyModel;
             sortProxy->setDynamicSortFilter(true);
             sortProxy->setSourceModel(baseModel);
 
-            KRearrangeColumnsProxyModel *columnFilterProxy = new KRearrangeColumnsProxyModel(
+            auto *columnFilterProxy = new KRearrangeColumnsProxyModel(
                 sortProxy);
             columnFilterProxy->setSourceColumns(
                 QVector<int>() << Akonadi::ETMCalendar::CollectionTitle);
             columnFilterProxy->setSourceModel(sortProxy);
 
-            QItemSelectionModel *qsm
+            auto *qsm
                 = new QItemSelectionModel(columnFilterProxy, columnFilterProxy);
 
-            KCheckableProxyModel *selection = new KCheckableProxyModel;
+            auto *selection = new KCheckableProxyModel;
             selection->setSourceModel(columnFilterProxy);
             selection->setSelectionModel(qsm);
 
