@@ -1,28 +1,12 @@
 /*
   This file is part of KOrganizer.
-  Copyright (c) 2007 Till Adam <adam@kde.org>
+  SPDX-FileCopyrightText: 2007 Till Adam <adam@kde.org>
 
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Andras Mantia <andras@kdab.com>
-  Copyright (c) 2010 Sérgio Martins <sergio.martins@kdab.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
+  SPDX-FileCopyrightText: 2010 Sérgio Martins <sergio.martins@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "kotimelineview.h"
@@ -35,8 +19,8 @@
 KOTimelineView::KOTimelineView(QWidget *parent)
     : KOEventView(parent)
 {
-    QVBoxLayout *vbox = new QVBoxLayout(this);
-    vbox->setContentsMargins(0, 0, 0, 0);
+    auto *vbox = new QVBoxLayout(this);
+    vbox->setContentsMargins({});
     mTimeLineView = new EventViews::TimelineView(this);
     vbox->addWidget(mTimeLineView);
     mEventPopup = eventPopup();
